pub enum StackCommands {
New {
name: String,
},
Push {
branch: Option<String>,
},
Status,
Rebase,
Pop,
Log,
}Variants
New
Create a new stack anchored at the current branch
Push
Push a new branch onto the stack
Status
Show status of the current stack
Rebase
Cascade rebase the entire stack from base to tip
Pop
Remove the top branch from the stack
Log
Show commits grouped by branch in the stack